@@ -1,19 +1,23 @@
-from typing import Any, Callable, Generator, List, Tuple, Optional, Dict, Union
+from typing import Any, Callable, Generator, List, Tuple, Dict, Union
 
 
 class Pipeline(object):
-    """Class that contains steps representing operations to be sequentially executed.
+    """Class that contains steps representing operations 
+    to be sequentially executed.
     Thanks to Generetors Tasks are lazily evaluated until run method is call.
     """
 
-    def __init__(self, steps: List[Union[Tuple[str, Callable], Tuple[str, Callable, Dict]]]) -> None:
+    def __init__(
+        self, steps: List[Union[Tuple[str, Callable], Tuple[str, Callable, Dict]]]
+    ) -> None:
         self.stream = ()  # empty generator needed to init the stream
         self.steps = steps
         self.output = None
         self.names = []
 
     def __call__(self, gen) -> Generator:
-        """ Implementation of special call method to allow a Pipeline object to receive an other Pipeline object"""
+        """ Implementation of special call method to allow a Pipeline object to receive 
+        an other Pipeline object"""
         self.stream = gen
         self.prepare()
         return self.stream
